==> haskell-storable-tuple-0.1-131.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 storable-tuple
version:              0.1
visibility:           public
id:                   storable-tuple-0.1-E3toVoSieYQBrCyQU81w2Y
key:                  storable-tuple-0.1-E3toVoSieYQBrCyQU81w2Y
license:              BSD-3-Clause
maintainer:           Henning Thielemann <storable@henning-thielemann.de>
author:               Henning Thielemann <storable@henning-thielemann.de>
stability:            Experimental
homepage:             http://code.haskell.org/~thielema/storable-tuple/
synopsis:             Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.
    Note however, that the original purpose of the @Storable@ class
    was the transfer of primitive types between Haskell and foreign code.
    This purpose was already extended by HSC,
    which creates @Storable@ instances for records from C header files.
    Nonetheless,
    @Storable@ instances for tuples were omitted from @base@ by intention.
    Instead of using the orphan instances from this package,
    you may instead use the custom class or the wrapper type
    from the module @Foreign.Storable.Record.Tuple@
    from the package @storable-record@.

category:             Data, Foreign
abi:                  f2d816c3f5a7ca910c9675a014964253
exposed:              True
exposed-modules:      Foreign.Storable.Tuple
import-dirs:          /usr/lib/ghc-9.6.6/site-local/storable-tuple-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/storable-tuple-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/storable-tuple-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-storable-tuple
hs-libraries:         HSstorable-tuple-0.1-E3toVoSieYQBrCyQU81w2Y
depends:
    base-4.18.2.1 base-orphans-0.9.3-JybUSC3tjiTK5xbDkdemoL
    storable-record-0.0.7-ESrd59kS9s1AVyw7g1zVT6
    utility-ht-0.0.17.2-FCtUbDIssee2G1L1Lv2g90

haddock-interfaces:
    /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock

haddock-html:         /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-tuple-0.1-132-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 storable-tuple
version:              0.1
visibility:           public
id:                   storable-tuple-0.1-6yASgZHaMHPLF3C5HDJO4X
key:                  storable-tuple-0.1-6yASgZHaMHPLF3C5HDJO4X
license:              BSD-3-Clause
maintainer:           Henning Thielemann <storable@henning-thielemann.de>
author:               Henning Thielemann <storable@henning-thielemann.de>
stability:            Experimental
homepage:             http://code.haskell.org/~thielema/storable-tuple/
synopsis:             Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.
    Note however, that the original purpose of the @Storable@ class
    was the transfer of primitive types between Haskell and foreign code.
    This purpose was already extended by HSC,
    which creates @Storable@ instances for records from C header files.
    Nonetheless,
    @Storable@ instances for tuples were omitted from @base@ by intention.
    Instead of using the orphan instances from this package,
    you may instead use the custom class or the wrapper type
    from the module @Foreign.Storable.Record.Tuple@
    from the package @storable-record@.

category:             Data, Foreign
abi:                  e299ec4edb09be1ff57070cea79fa867
exposed:              True
exposed-modules:      Foreign.Storable.Tuple
import-dirs:          /usr/lib/ghc-9.6.6/site-local/storable-tuple-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/storable-tuple-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/storable-tuple-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-storable-tuple
hs-libraries:         HSstorable-tuple-0.1-6yASgZHaMHPLF3C5HDJO4X
depends:
    base-4.18.2.1 base-orphans-0.9.3-JybUSC3tjiTK5xbDkdemoL
    storable-record-0.0.7-AG9fXRnJb4K8ASmvN9MjfW
    utility-ht-0.0.17.2-9ryTCp5DXpz5HmwvPaZxIP

haddock-interfaces:
    /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock

haddock-html:         /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
